diff -uNr libdvbpsi-trunk-r170/src/descriptors/dr_43.c libdvbpsi-trunk-r170+dr43/src/descriptors/dr_43.c
--- libdvbpsi-trunk-r170/src/descriptors/dr_43.c	1970-01-01 01:00:00.000000000 +0100
+++ libdvbpsi-trunk-r170+dr43/src/descriptors/dr_43.c	2008-04-25 19:10:25.000000000 +0200
@@ -0,0 +1,140 @@
+/*****************************************************************************
+ * dr_43.c
+ * (c)2001-2008 VideoLAN
+ * $Id: $
+ *
+ * Authors: Johann Hanne
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ *****************************************************************************/
+
+
+#include "config.h"
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#if defined(HAVE_INTTYPES_H)
+#include <inttypes.h>
+#elif defined(HAVE_STDINT_H)
+#include <stdint.h>
+#endif
+
+#include "../dvbpsi.h"
+#include "../dvbpsi_private.h"
+#include "../descriptor.h"
+
+#include "dr_43.h"
+
+
+/*****************************************************************************
+ * dvbpsi_DecodeSatDelivSysDr
+ *****************************************************************************/
+dvbpsi_sat_deliv_sys_dr_t * dvbpsi_DecodeSatDelivSysDr(
+                                        dvbpsi_descriptor_t * p_descriptor)
+{
+  dvbpsi_sat_deliv_sys_dr_t * p_decoded;
+
+  /* Check the tag */
+  if(p_descriptor->i_tag != 0x43)
+  {
+    DVBPSI_ERROR_ARG("dr_43 decoder", "bad tag (0x%x)", p_descriptor->i_tag);
+    return NULL;
+  }
+
+  /* Don't decode twice */
+  if(p_descriptor->p_decoded)
+    return p_descriptor->p_decoded;
+
+  /* Allocate memory */
+  p_decoded =
+        (dvbpsi_sat_deliv_sys_dr_t*)malloc(sizeof(dvbpsi_sat_deliv_sys_dr_t));
+  if(!p_decoded)
+  {
+    DVBPSI_ERROR("dr_43 decoder", "out of memory");
+    return NULL;
+  }
+
+  /* Decode data */
+  p_decoded->i_frequency         =   (uint32_t)(p_descriptor->p_data[0] << 24)
+                                   | (uint32_t)(p_descriptor->p_data[1] << 16)
+                                   | (uint32_t)(p_descriptor->p_data[2] <<  8)
+                                   | (uint32_t)(p_descriptor->p_data[3]);
+  p_decoded->i_orbital_position  =   (uint16_t)(p_descriptor->p_data[4] << 8)
+                                   | (uint16_t)(p_descriptor->p_data[5]);
+  p_decoded->i_west_east_flag    =   (p_descriptor->p_data[6] >> 7) & 0x01;
+  p_decoded->i_polarization      =   (p_descriptor->p_data[6] >> 5) & 0x03;
+  p_decoded->i_roll_off          =   (p_descriptor->p_data[6] >> 3) & 0x03;
+  p_decoded->i_modulation_system =   (p_descriptor->p_data[6] >> 2) & 0x01;
+  p_decoded->i_modulation_type   =    p_descriptor->p_data[6] & 0x03;
+  p_decoded->i_symbol_rate       =   (uint32_t)(p_descriptor->p_data[7] << 20)
+                                   | (uint32_t)(p_descriptor->p_data[8] << 12)
+                                   | (uint32_t)(p_descriptor->p_data[9] <<  4)
+                                   | (uint32_t)((p_descriptor->p_data[10] >> 4) & 0x0f);
+  p_decoded->i_fec_inner         =    p_descriptor->p_data[10] & 0x0f;
+
+  p_descriptor->p_decoded = (void*)p_decoded;
+
+  return p_decoded;
+}
+
+
+/*****************************************************************************
+ * dvbpsi_GenSatDelivSysDr
+ *****************************************************************************/
+dvbpsi_descriptor_t * dvbpsi_GenSatDelivSysDr(
+                                        dvbpsi_sat_deliv_sys_dr_t * p_decoded,
+                                        int b_duplicate)
+{
+  /* Create the descriptor */
+  dvbpsi_descriptor_t * p_descriptor =
+        dvbpsi_NewDescriptor(0x43, 11, NULL);
+
+  if(p_descriptor)
+  {
+    /* Encode data */
+    p_descriptor->p_data[0]  =     (p_decoded->i_frequency >> 24)       & 0xff;
+    p_descriptor->p_data[1]  =     (p_decoded->i_frequency >> 16)       & 0xff;
+    p_descriptor->p_data[2]  =     (p_decoded->i_frequency >>  8)       & 0xff;
+    p_descriptor->p_data[3]  =      p_decoded->i_frequency              & 0xff;
+    p_descriptor->p_data[4]  =     (p_decoded->i_orbital_position >> 8) & 0xff;
+    p_descriptor->p_data[5]  =      p_decoded->i_orbital_position       & 0xff;
+    p_descriptor->p_data[6]  =    ((p_decoded->i_west_east_flag         & 0x01) << 7)
+                                | ((p_decoded->i_polarization           & 0x03) << 5)
+                                | ((p_decoded->i_roll_off               & 0x03) << 3)
+                                | ((p_decoded->i_modulation_system      & 0x01) << 2)
+                                |  (p_decoded->i_modulation_type        & 0x03);
+    p_descriptor->p_data[7]  =     (p_decoded->i_symbol_rate >> 20)     & 0xff;
+    p_descriptor->p_data[8]  =     (p_decoded->i_symbol_rate >> 12)     & 0xff;
+    p_descriptor->p_data[9]  =     (p_decoded->i_symbol_rate >>  4)     & 0xff;
+    p_descriptor->p_data[10] =    ((p_decoded->i_symbol_rate <<  4)     & 0xf0)
+                                |  (p_decoded->i_fec_inner              & 0x0f);
+
+    if(b_duplicate)
+    {
+      /* Duplicate decoded data */
+      dvbpsi_sat_deliv_sys_dr_t * p_dup_decoded =
+        (dvbpsi_sat_deliv_sys_dr_t*)malloc(sizeof(dvbpsi_sat_deliv_sys_dr_t));
+      if(p_dup_decoded)
+        memcpy(p_dup_decoded, p_decoded, sizeof(dvbpsi_sat_deliv_sys_dr_t));
+
+      p_descriptor->p_decoded = (void*)p_dup_decoded;
+    }
+  }
+
+  return p_descriptor;
+}
diff -uNr libdvbpsi-trunk-r170/src/descriptors/dr_43.h libdvbpsi-trunk-r170+dr43/src/descriptors/dr_43.h
--- libdvbpsi-trunk-r170/src/descriptors/dr_43.h	1970-01-01 01:00:00.000000000 +0100
+++ libdvbpsi-trunk-r170+dr43/src/descriptors/dr_43.h	2008-04-25 19:10:25.000000000 +0200
@@ -0,0 +1,111 @@
+/*****************************************************************************
+ * dr_43.h
+ * (c)2001-2008 VideoLAN
+ * $Id: $
+ *
+ * Authors: Johann Hanne
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *
+ *****************************************************************************/
+
+/*!
+ * \file <dr_43.h>
+ * \author Johann Hanne
+ * \brief Application interface for the DVB satellite delivery system
+ *        descriptor decoder and generator.
+ *
+ * Application interface for the DVB satellite delivery system descriptor
+ * decoder and generator. This descriptor's definition can be found in
+ * ETSI EN 300 468 section 6.2.13.2.
+ */
+
+#ifndef _DVBPSI_DR_43_H_
+#define _DVBPSI_DR_43_H_
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+/*****************************************************************************
+ * dvbpsi_sat_deliv_sys_dr_t
+ *****************************************************************************/
+/*!
+ * \struct dvbpsi_sat_deliv_sys_dr_s
+ * \brief satellite delivery system descriptor structure.
+ *
+ * This structure is used to store a decoded satellite delivery system
+ * descriptor. (ETSI EN 300 468 section 6.2.13.2).
+ */
+/*!
+ * \typedef struct dvbpsi_sat_deliv_sys_dr_s dvbpsi_sat_deliv_sys_dr_t
+ * \brief dvbpsi_sat_deliv_sys_dr_t type definition.
+ */
+typedef struct dvbpsi_sat_deliv_sys_dr_s
+{
+  uint32_t     i_frequency;                         /*!< frequency */
+  uint16_t     i_orbital_position;                  /*!< orbital position */
+  uint8_t      i_west_east_flag;                    /*!< west east flag */
+  uint8_t      i_polarization;                      /*!< polarization */
+  uint8_t      i_roll_off;                          /*!< roll off */
+  uint8_t      i_modulation_system;                 /*!< modulation system */
+  uint8_t      i_modulation_type;                   /*!< modulation type */
+  uint32_t     i_symbol_rate;                       /*!< symbol rate */
+  uint8_t      i_fec_inner;                         /*!< FEC inner */
+
+} dvbpsi_sat_deliv_sys_dr_t;
+
+
+/*****************************************************************************
+ * dvbpsi_DecodeSatDelivSysDr
+ *****************************************************************************/
+/*!
+ * \fn dvbpsi_sat_deliv_sys_dr_t * dvbpsi_DecodeSatDelivSysDr(
+                                        dvbpsi_descriptor_t * p_descriptor)
+ * \brief satellite delivery system descriptor decoder.
+ * \param p_descriptor pointer to the descriptor structure
+ * \return a pointer to a new satellite delivery system descriptor structure
+ * which contains the decoded data.
+ */
+dvbpsi_sat_deliv_sys_dr_t* dvbpsi_DecodeSatDelivSysDr(
+                                        dvbpsi_descriptor_t * p_descriptor);
+
+
+/*****************************************************************************
+ * dvbpsi_GenSatDelivSysDr
+ *****************************************************************************/
+/*!
+ * \fn dvbpsi_descriptor_t * dvbpsi_GenSatDelivSysDr(
+                        dvbpsi_sat_deliv_sys_dr_t * p_decoded, int b_duplicate)
+ * \brief satellite delivery system descriptor generator.
+ * \param p_decoded pointer to a decoded satellite delivery system descriptor
+ * descriptor structure
+ * \param b_duplicate if non zero then duplicate the p_decoded structure into
+ * the descriptor
+ * \return a pointer to a new descriptor structure which contains encoded data.
+ */
+dvbpsi_descriptor_t * dvbpsi_GenSatDelivSysDr(
+                                        dvbpsi_sat_deliv_sys_dr_t * p_decoded,
+                                        int b_duplicate);
+
+
+#ifdef __cplusplus
+};
+#endif
+
+#else
+#error "Multiple inclusions of dr_43.h"
+#endif
diff -uNr libdvbpsi-trunk-r170/src/descriptors/dr.h libdvbpsi-trunk-r170+dr43/src/descriptors/dr.h
--- libdvbpsi-trunk-r170/src/descriptors/dr.h	2008-04-25 07:54:40.000000000 +0200
+++ libdvbpsi-trunk-r170+dr43/src/descriptors/dr.h	2008-04-25 19:12:28.000000000 +0200
@@ -47,6 +47,7 @@
 #include "dr_0e.h"
 #include "dr_0f.h"
 #include "dr_42.h"
+#include "dr_43.h"
 #include "dr_45.h"
 #include "dr_47.h"
 #include "dr_48.h"
diff -uNr libdvbpsi-trunk-r170/src/Makefile.am libdvbpsi-trunk-r170+dr43/src/Makefile.am
--- libdvbpsi-trunk-r170/src/Makefile.am	2008-04-25 07:54:40.000000000 +0200
+++ libdvbpsi-trunk-r170+dr43/src/Makefile.am	2008-04-25 19:12:14.000000000 +0200
@@ -31,6 +31,7 @@
                      descriptors/dr_0e.h \
                      descriptors/dr_0f.h \
                      descriptors/dr_42.h \
+                     descriptors/dr_43.h \
                      descriptors/dr_45.h \
                      descriptors/dr_47.h \
                      descriptors/dr_48.h \
@@ -58,6 +59,7 @@
                   descriptors/dr_0e.c \
                   descriptors/dr_0f.c \
                   descriptors/dr_42.c \
+                  descriptors/dr_43.c \
                   descriptors/dr_45.c \
                   descriptors/dr_47.c \
                   descriptors/dr_48.c \
